@@ -30,6 +30,7 @@ const (
 	AwsDBInstance                    = "aws_db_instance"
 	AwsIamRole                       = "aws_iam_role"
 	AwsIamRolePolicy                 = "aws_iam_role_policy"
+	AwsIamGroup                      = "aws_iam_group"
 	AwsIamGroupPolicy                = "aws_iam_group_policy"
 	AwsIamPolicy                     = "aws_iam_policy"
 	AwsIamAccessKey                  = "aws_iam_access_key"
@@ -44,12 +45,14 @@ const (
 	AwsGuardDutyDetector             = "aws_guardduty_detector"
 	AwsMqBroker                      = "aws_mq_broker"
 	AwsRedshiftCluster               = "aws_redshift_cluster"
+	AwsRedshiftParameterGroup        = "aws_redshift_parameter_group"
 	AwsRdsCluster                    = "aws_rds_cluster"
 	AwsRoute53Record                 = "aws_route53_record"
 	AwsSecurityGroup                 = "aws_security_group"
 	AwsWorkspacesWorkspace           = "aws_workspaces_workspace"
 	AwsNeptuneCluster                = "aws_neptune_cluster"
 	AwsSecretsManagerSecret          = "aws_secretsmanager_secret"
+	AwsSecretsManagerSecretRotation  = "aws_secretsmanager_secret_rotation"
 	AwsEcrRepository                 = "aws_ecr_repository"
 	AwsKmsKey                        = "aws_kms_key"
 	AwsKinesisStream                 = "aws_kinesis_stream"
@@ -62,6 +65,7 @@ const (
 	AwsLbListener                    = "aws_lb_listener"
 	AwsLbTargetGroup                 = "aws_lb_target_group"
 	AwsElb                           = "aws_elb"
+	AwsElbPolicy                     = "aws_load_balancer_policy"
 	AwsElasticsearchDomain           = "aws_elasticsearch_domain"
 	AwsElasticsearchDomainPolicy     = "aws_elasticsearch_domain_policy"
 	AwsEfsFileSystemPolicy           = "aws_efs_file_system_policy"
@@ -70,4 +74,27 @@ const (
 	AwsS3Bucket                      = "aws_s3_bucket"
 	AwsS3BucketPublicAccessBlock     = "aws_s3_bucket_public_access_block"
 	AwsS3BucketPolicy                = "aws_s3_bucket_policy"
+	AwsSqsQueue                      = "aws_sqs_queue"
+	AwsSqsQueuePolicy                = "aws_sqs_queue_policy"
+	AwsSnsTopic                      = "aws_sns_topic"
+	AwsSnsTopicPolicy                = "aws_sns_topic_policy"
+	AwsLaunchConfiguration           = "aws_launch_configuration"
+	AwsEc2Instance                   = "aws_instance"
+	AwsEc2NetworkInterface           = "aws_network_interface"
+	AwsCognitoUserPool               = "aws_cognito_user_pool"
+	AwsLambdaFunction                = "aws_lambda_function"
+	AwsAcmCertificate                = "aws_acm_certificate"
+	AwsSagemakerNotebookInstance     = "aws_sagemaker_notebook_instance"
+	AwsSagemakerModel                = "aws_sagemaker_model"
+	AwsDmsReplicationInstance        = "aws_dms_replication_instance"
+	AwsEksCluster                    = "aws_eks_cluster"
+	AwsEksNodeGroup                  = "aws_eks_node_group"
+	AwsCodebuildProject              = "aws_codebuild_project"
+	AwsVpc                           = "aws_vpc"
+	AwsEmrCluster                    = "aws_emr_cluster"
+	AwsMskCluster                    = "aws_msk_cluster"
+	AwsBackupVault                   = "aws_backup_vault"
+	AwsAppMeshMesh                   = "aws_appmesh_mesh"
+	AwsRAMResourceShare              = "aws_ram_resource_share"
+	AwsAppAutoscalingPolicy          = "aws_appautoscaling_policy"
 )
